tests API documentation

# tests

The test modules, which can be run with `pytest` once the package is installed and `pip install -r requirements.txt` has been run. Some of these tests act as little demos of how to use the package, so you may find them helpful to see the imagined workflow of the package.

View Source

    1"""
    2The test modules, which can be run with `pytest` once the package is installed and
    3`pip install -r requirements.txt` has been run. Some of these tests act as little
    4demos of how to use the package, so you may find them helpful to see the imagined
    5workflow of the package.
    6"""